require File.join(File.dirname(__FILE__), 'certificate_helpers')

module Certificates
  class CertificateLogger
    include CertificateHelpers

    def initialize
      @log = Logger.new '/var/log/pe-puppet-dashboard/certificate_manager.log'
      @log.formatter = proc { |sev, datetime, prog, msg|
        "#{sev} [#{datetime.strftime "%Y-%m-%d %H:%M:%S"}] #{msg}\n" }
    end

    def log_action(userinfo, certificatename, action)
      username = userinfo.username
      role = userinfo.roles.first.name.capitalize
      begin
        @log.debug "#{role} user #{username} attempting to #{action} #{certificatename}"
        api_response = yield
        if api_response.respond_to?(:code)
          # we have a full-fledged HTTP response
          status_code = api_response.code
          message = api_response.body
        else
          # we have a number passed in by cache purging
          status_code = api_response
          message = nil
        end
        @log.debug "#{role} user #{username} finished attempt to " +
                   "#{action} #{certificatename} with HTTP code #{status_code}"

        if is_successful?(status_code)
          @log.info "#{role} user #{username} executed #{action} on #{certificatename}"
        else
          @log.error "#{role} user #{username} failed to #{action} #{certificatename}" +
                     ". Server responded with #{message}."
        end
        api_response
      rescue
        @log.error "#{role} user #{username} failed to #{action} #{certificatename}" +
                   ". Server responded with #{message}."
        raise
      end
    end
  end
end
